#
# spec file for package kid3
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports
%global __requires_exclude qmlimport\\(Kid3.*
%if 0%{?suse_version} > 1500
%define qt_version 6
%else
%define qt_version 5
%endif

Name:           kid3
Version:        3.9.6
Release:        4.2
Summary:        Efficient ID3 Tag Editor
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://kid3.kde.org/
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
BuildRequires:  extra-cmake-modules
BuildRequires:  hicolor-icon-theme
BuildRequires:  id3lib-devel
BuildRequires:  kf%{qt_version}-filesystem
BuildRequires:  libxslt-tools
BuildRequires:  python3 >= 3.6
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF%{qt_version}DocTools)
BuildRequires:  cmake(KF%{qt_version}KIO)
BuildRequires:  cmake(Qt%{qt_version}Core)
BuildRequires:  cmake(Qt%{qt_version}DBus)
BuildRequires:  cmake(Qt%{qt_version}Gui)
BuildRequires:  cmake(Qt%{qt_version}LinguistTools)
BuildRequires:  cmake(Qt%{qt_version}Multimedia)
BuildRequires:  cmake(Qt%{qt_version}Network)
BuildRequires:  cmake(Qt%{qt_version}Qml)
BuildRequires:  cmake(Qt%{qt_version}Quick)
BuildRequires:  cmake(Qt%{qt_version}Test)
BuildRequires:  cmake(Qt%{qt_version}UiTools)
BuildRequires:  cmake(Qt%{qt_version}Widgets)
BuildRequires:  cmake(Qt%{qt_version}Xml)
BuildRequires:  config(docbook-xsl-stylesheets)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(libavcodec) >= 61
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libchromaprint)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(taglib) >= 1.4
BuildRequires:  pkgconfig(vorbis)
Requires:       %{name}-core = %{version}
Requires:       libxslt-tools
Requires:       xdg-utils
# kid3 and kid3-qt can exist together on a system but the user will have two packages with the same functionality.
Conflicts:      kid3-qt = %{version}

%description
f you want to easily tag multiple MP3, Ogg/Vorbis, Opus, DSF, FLAC,
MPC, MP4/AAC, MP2, Opus, Speex, TrueAudio, WavPack and WMA files
(e.g. full albums) without typing the same information again and
again and have control over both ID3v1 and ID3v2 tags,
then Kid3 is the program you are looking for.

With Kid3 you can:
- Edit ID3v1.1 tags
- Edit all ID3v2.3 and ID3v2.4 frames
- Convert between ID3v1.1, ID3v2.3 and ID3v2.4 tags
- Edit tags in MP3, Ogg/Vorbis, FLAC, MPC, MP4/AAC, MP2, Speex,
  TrueAudio, WavPack, WMA, AIFF and WAV files
- Edit tags of multiple files, e.g. the artist, album, year and
  genre of all files of an album typically have the same values
  and can be set together.
- Generate tags from filenames
- Generate tags from the contents of tag fields
- Generate filenames from tags
- Rename and create directories from tags
- Generate playlist files
- Automatically convert upper and lower case and replace strings
- Import from freedb2.org, MusicBrainz, Discogs, Amazon and other
  sources of album data
- Export tags as CSV, HTML, playlists, Kover XML and in other formats
- Edit synchronized lyrics and event timing codes,import and export LRC files

This package uses KDE libraries, if you do not use KDE you should use kid3-qt.
For a commandline interface you can use kid3-cli.

%package qt
Summary:        Efficient ID3 Tag Editor
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-core = %{version}
Requires:       xdg-utils
# kid3 and kid3-qt can exist together on a system but the user will have two packages with the same functionality.
Conflicts:      kid3 = %{version}
Obsoletes:      kid3-qt < %{version}

%description qt
With Kid3 you can:
  - Edit ID3v1.1 tags
  - Edit all ID3v2.3 and ID3v2.4 frames
  - Convert between ID3v1.1, ID3v2.3 and ID3v2.4 tags
  - Edit tags in MP3, Ogg/Vorbis, FLAC, MPC, APE, MP4/AAC, MP2, Speex,
    TrueAudio, WavPack, WMA, WAV, AIFF files and tracker modules (MOD,
    S3M, IT, XM).
  - Edit tags of multiple files, e.g. the artist, album, year and genre
    of all files of an album typically have the same values and can be
    set together.
  - Generate tags from filenames
  - Generate tags from the contents of tag fields
  - Generate filenames from tags
  - Generate playlist files
  - Automatic case conversion and string translation
  - Import and export album data
  - Import from gnudb.org, TrackType.org, MusicBrainz, Discogs, Amazon

This package does not use KDE libraries, if you use KDE you should use kid3.
For a commandline interface you can use kid3-cli.

%package cli
Summary:        Efficient ID3 Tag Editor
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-core = %{version}

%description cli
With Kid3 you can:
  - Edit ID3v1.1 tags
  - Edit all ID3v2.3 and ID3v2.4 frames
  - Convert between ID3v1.1, ID3v2.3 and ID3v2.4 tags
  - Edit tags in MP3, Ogg/Vorbis, FLAC, MPC, APE, MP4/AAC, MP2, Speex,
    TrueAudio, WavPack, WMA, WAV, AIFF files and tracker modules (MOD,
    S3M, IT, XM).
  - Edit tags of multiple files, e.g. the artist, album, year and genre
    of all files of an album typically have the same values and can be
    set together.
  - Generate tags from filenames
  - Generate tags from the contents of tag fields
  - Generate filenames from tags
  - Generate playlist files
  - Automatic case conversion and string translation
  - Import and export album data
  - Import from gnudb.org, TrackType.org, MusicBrainz, Discogs, Amazon

This package contains a command line interface for Kid3, for a GUI you can
use kid3-qt or kid3.

%package doc
Summary:        Documentation for %{name}
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name} = %{version}

%description doc
This package provides documentation and help files for %{name}.

%package qt-doc
Summary:        Documentation for %{name}-qt
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-qt = %{version}

%description qt-doc
This package provides documentation and help files for %{name}-qt.

%package  core
Summary:        Efficient ID3 Tag Editor: Libraries and Data
Group:          Productivity/Multimedia/Sound/Utilities
Recommends:     kid3-trans-lang = %{version}

%description  core
This package contains common libraries and data files used by kid3, kid3-qt, and kid3-cli.

%lang_package -n %{name}-core

%prep
%autosetup -p1

%build
export LC_ALL=en_US.UTF-8
options+="-DWITH_LIBDIR=%{_lib}/kid3 -DWITH_PLUGINSDIR=%{_lib}/kid3/plugins "
options+="-DWITH_CHROMAPRINT_FFMPEG=ON -DWITH_FFMPEG=ON -DWITH_GSTREAMER=ON "
options+="-DWITH_DOCDIR=share/doc/packages/kid3-qt "
options+="-DCMAKE_SKIP_RPATH=ON -DWITH_QMLDIR=%{_lib}/qt%{qt_version}/qml/kid3 "
%if %{qt_version} == 6
%{cmake_kf6} -DBUILD_WITH_QT6=ON $options
%{kf6_build}
%else
%cmake_kf5 -d build -- $options
%make_jobs
%endif

%install
%if %{qt_version} == 6
%{kf6_install}
%else
%kf5_makeinstall -C build
%endif

pushd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
gzip -dS .svgz kid3.svgz
mv kid3 kid3.svg
popd

chmod 644 %{buildroot}%{_kf5_applicationsdir}/org.kde.kid3.desktop

%find_lang %{name} %{name}-core.lang --without-kde --with-qt --all-name --without-mo

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
cat <<EOF >%{buildroot}%{_sysconfdir}/ld.so.conf.d/kid3.conf
%{_libdir}/kid3
EOF

%post core -p /sbin/ldconfig

%postun core -p /sbin/ldconfig

%files
%dir %{_datadir}/metainfo
%{expand:%{_kf%{qt_version}_bindir}}/kid3
%{expand:%{_kf%{qt_version}_iconsdir}}/hicolor/*/apps/kid3.*
%{expand:%{_kf%{qt_version}_kxmlguidir}}/kid3/
%{expand:%{_kf%{qt_version}_applicationsdir}}/org.kde.kid3.desktop
%{expand:%{_kf%{qt_version}_appstreamdir}}/org.kde.kid3.appdata.xml

%files qt
%dir %{_datadir}/metainfo
%{_datadir}/applications/org.kde.kid3-qt.desktop
%{_datadir}/metainfo/org.kde.kid3-qt.appdata.xml
%{_bindir}/kid3-qt
%{_datadir}/icons/hicolor/*/apps/kid3-qt.*
%{_mandir}/man1/kid3-qt.1%{ext_man}
%{_mandir}/*/man1/kid3-qt.1%{ext_man}

%files cli
%{_bindir}/kid3-cli
%{_mandir}/man1/kid3-cli.1%{ext_man}
%{_mandir}/*/man1/kid3-cli.1%{ext_man}

%files core
%doc AUTHORS ChangeLog README
%license COPYING LICENSE
%{_libdir}/kid3/
%{_libdir}/qt%{qt_version}/qml/kid3/
%config %{_sysconfdir}/ld.so.conf.d/kid3.conf
%{_datadir}/dbus-1/interfaces/org.kde.Kid3.xml
%{_mandir}/man1/kid3.1%{ext_man}
%{_mandir}/*/man1/kid3.1%{ext_man}

%files doc
%doc %{expand:%{_kf%{qt_version}_htmldir}}/*/kid3/

%files qt-doc
%{_docdir}/kid3-qt/

%files -n %{name}-core-lang -f %{name}-core.lang
%dir %{_datadir}/kid3
%dir %{_datadir}/kid3/translations

%changelog
* Mon Mar 31 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Use pkgconfig(libavcodec) to allow building with ffmpeg-*-mini.
* Fri Jan 24 2025 Dave Plater <davejplater@gmail.com>
- Force to build with ffmpeg-7
* Thu Oct 31 2024 Jiri Slaby <jslaby@suse.cz>
- build with qt6 (the default in upstream provided binaries)
  (only on suse_version > 15.0)
* Sat Sep 21 2024 enzokiel@kabelmail.de
- Update to version 3.9.6
  * New:
    + Show preview for multiple embedded pictures.
    + Simplified editing of MP3 audiobooks in a "Chapters" frame
    edit dialog.
    + Arabic, Esperanto, Galician and Georgian translations.
  * Improved:
    + macOS: Building, signing and notarizing packages.
  * Fixed:
    + Embed lyrics action.
    + gnudb.org import, a registered e-mail address can be set in
    the "Token" UI control.
    + KDE 6: Install directory for kid3ui.rc.
    + Android: Building with arm64-v8a and x86_64 architectures.
    + Android: Use MANAGE_EXTERNAL_STORAGE permission to manage all
    files on a storage device.
    + Android: Saving picture tags.
    + Haiku: Installation paths.
* Sat Feb 24 2024 enzokiel@kabelmail.de
- Update to version 3.9.5
  * New:
    + Keyboard shortcuts for play toolbar.
    + Option "Audio output" in "User Actions" settings tab.
    + Support WebP format for pictures.
  * Improved:
    + Clicking again on 1 star makes star rating disappear.
    + Support '\|' to escape string list separators.
  * Fixed:
    + Support multiple values in APE text items.
    + Building with TagLib 2.0.
    + Building from macOS with arm64.
    + Building snap packages.
* Thu Dec 28 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Sun Oct 15 2023 Wang Jun <badboywj@gmail.com>
- Update to version 3.9.4
  * New:
    + All the official binaries are built with Qt 6. For macOS, the
    Darwin-amd64.dmg file is now the Qt 6 version, whereas systems older
    than Mojave need the package Darwin-Qt5.dmg. The string replacement
    settings stored by Qt 6 are not compatible with Qt 5 because a
    different encoding is used.
    + Option "Select file on play" in "User Actions" settings tab.
  * Improved:
    + Click on play tool bar time toggles between elapsed and remaining
    time.
    + The visibility and docked area of the play tool bar are restored.
    + ID3v1: When setting multiple genres, use first supported element.
    + Qt6: Use SVG icons for better performance in file list and dialog.
  * Fixed:
    + Do not mark all non-unified frames as modified if any non-unified
    frame is changed.
    + Crash in Id3libMetadata when clicking Edit on unsupported frame.
    + Setting text encoding on TXXX frames with TaglibMetadata.
    + Skip non letter characters for first letter uppercase format.
    + Discogs import: Fix values in Artist, Arranger and Performer frames,
    use "genres" if "styles" is empty, fetch correct cover art,
    support vinyl track numbers like A1.
    + Qt6: Crash when adding item to config table.
    + Qt6: Larger media player slider, do not repeat when last song has
    been played.
    + Windows, TaglibMetadata: Support files larger than 2 GB.
    + Windows, OggFlacMetadata: Build without libssp-0.dll.
    + Windows, Mp4v2Metadata: Fix saving with file names containing non
    ASCII characters.
* Thu Jan 12 2023 enzokiel@kabelmail.de
- Update to version 3.9.3
  * New:
    + User action script to fix ID3v2 standard violations.
  * Improved:
    + Accept letters in track numbers when setting tags from
    filename.
    + Embed lyrics: Use letras.com instead of lyrics.wikia.com.
  * Fixed:
    + Crash upon termination when qml and qmlview actions have been
    used.
    + Abort when invalid keys are used for FLAC Vorbis comments.
    + Use of non-BMP Unicode characters with TagLib.
    + Error description when saving files fails.
    + Discogs import.
    + Building with Musl libc.
    + Windows: Handling of common path in multiple command line
    arguments.
* Sun Aug  7 2022 ecsos <ecsos@opensuse.org>
- Update ot 3.9.2
  * New:
    + Support DSDIFF (DFF) files.
    + MP4: Support for audio book chapters, only with Mp4v2Metadata plugin.
    + Norwegian Nynorsk translation.
  * Improved:
    + Allow playlist file name formats to be edited.
    + URLs with search results from web browser can be entered in the import
    dialogs (Amazon, Discogs, gnudb.org, MusicBrainz).
    + New style for macOS icon.
    + kid3-cli: Encoding detection for text file import and export.
    + kid3-cli: Set rating as star count with 'set ratingstars'.
    + Build with latest mp4v2 library.
  * Fixed:
    + Wrong frames are changed if track number is changed when importing.
    + MP4: Editing of free form atoms with four letter names.
    + Amazon import.
* Sat Jan 15 2022 enzokiel@kabelmail.de
- Update to version 3.9.1
  * New:
    + Slovenian translation.
  * Fixed:
    + Crash when tags are displayed in the file list, a tag is
    removed and then saved or when the tag is reverted.
    + With "Filename Format/Use for playlist and folder names" it
    is not possible to rename a folder to multiple path
    components when a string replacement for "/" is configured.
    + With "Filename Format/Use for playlist and folder names",
    when path components in folders or playlists contain a ".",
    the part after the dot is not formatted.
    + Discogs import.
    + MP4: "No Tag" is not displayed in file list for files without
    metadata.
    + MP4: Metadata is not stripped from files when tag is removed
    (requires new TagLib).
    + Android: Import with HTTPS (Discogs, MusicBrainz) fails with
    "Error: TLS initialization failed".
* Sat Dec 18 2021 enzokiel@kabelmail.de
- Update to version 3.9.0
  * New:
    + Support for custom quick access frames.
    + Support standard tags as columns in the file list.
    + Option to use file format for playlist and folder names.
    + Basque and Icelandic translations.
    + kid3-cli: Command 'execute' to run QML scripts.
    + QML: Scripts to export and import in JSON format.
  * Improved:
    + KDE: Separate state config from settings config.
    + kid3-cli: Allow setting frame values from a file and storing
    to a file.
  * Fixed:
    + Discogs import.
    + Get tags from file names with spaces before the extension.
    + QML: Added support for Tag 3 where it was missing.
    + Android: Quick access frames configuration.
* Tue Jun 22 2021 enzokiel@kabelmail.de
- Update to version 3.8.7
  * New:
    + Russian handbook.
  * Fixed:
    + ID3v2: Wrong numeric strings for genres Fast Fusion, Fok,
    Folk Rock, Folklore, Funk, Fusion.
    + ID3v1: Genres Avant-Garde, Beat Music, Bebop, Britpop,
    Dancehall, Dark Wave, Euro House, Eurotechno, Fast Fusion,
    Folk Rock, Hip Hop, Jazz-Funk, Pop-Funk, Synth-Pop, Worldbeat
    cannot be set with TagLib version < 1.12.
    + Memory leak in the rare case where the file type is detected
    not by the extension but by the contents.
    + kid3-cli: Fields (sub-elements of a frame) with a non-string
    value cannot be set with id3lib.
- Changed BuildRequires to python3 >= 3.6 as python3 in Tumbleweed
  no longer provides python >= 3.6.
* Fri Mar 19 2021 ecsos <ecsos@opensuse.org>
- Update to 3.8.6
  * Improved:
    + Support Qt 6.
    + Windows: Provide nicer default style.
  * Fixed:
    + Windows 64-bit binary: Crash when using id3lib.
    + Discogs import.
    + Amazon import.
    + Removed TrackType.org import.
* Mon Feb  1 2021 enzokiel@kabelmail.de
- Shared libs libkid3-core.so and libkid3-gui.so are no longer
  versioned with the release tag.
- Fixed wrong date in file kid3.changes.
* Sun Jan 31 2021 enzokiel@kabelmail.de
- Update to version 3.8.5
  * New:
    + Language can be configured in "Appearance" tab of settings.
    + New action "Edit/Invert Selection".
    + kid3-cli: Command "config" to query and set configuration
    options.
    + Script to rewrite all tags of the selected files.
  * Improved:
    + Import multiple genres from Discogs and MusicBrainz.
    + Support import from Discogs JSON API when token is provided.
    + Snapshot builds can download the current translations.
    + Mac: Allow code signing.
  * Fixed:
    + Crash when adding Chapter frame.
    + Support ID3v2 Podcast Category (TCAT) and Podcast Keywords
    (TKWD).
    + Support for multiple genres with ID3v2.3.0.
    + Support MP4 values with multiple strings with TagLib.
* Fri Jan 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Sat Sep 26 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 3.8.4
  * New:
    + Section and file list shortcuts can be customized.
    + Activate parent/current folder with Ctrl-Up/Down.
    + Go to parent item in file list when left arrow key is
    pressed.
    + Header context menu options for custom or automatic column
    widths.
    + Add flatpak support.
    + Brazilian Portuguese translation.
  * Improved:
    + Support detection of tagged file types from contents when
    matching by extension does not succeed.
    + Show more details (type, bits, bitrate) for M4A, FLAC, AIFF,
    WAV.
    + Discogs import: Show year and format in album list.
    + Dialogs: Store window position and size in settings.
    + Mac: Enter key can activate entries in directory list.
    + Android: Only navigate between tagged files with [<], [>]
    buttons.
  * Fixed:
    + Do not duplicate pictures when pasting tags.
    + Discogs import: Get year when language is not English.
    + Keyboard shortcuts settings: Display correctly depending on
    language and operating system.
    + Android: Accept genre changes when focus lost and Enter not
    pressed.
    + Android: Fix translation.
    + Mac: Unlock files when changing permissions.
    + Flatpak: Move to trash works in KDE version.
* Sun May 10 2020 enzokiel@kabelmail.de
- update to version 3.8.3
  * New:
    + Keyboard shortcuts to navigate between the file and tag
    sections.
    + Script to apply English title capitalization to tags.
    + Script to transliterate ID3v1 tags to ASCII.
    + Korean and Swedish translations.
    + Catalan, Dutch, Italian, Swedish and Ukrainian handbooks.
  * Improved:
    + Better compatibility with dark mode and custom themes.
    + Support dragging multiple header rows in import table.
    + User interface strings follow KDE HIG vocabulary.
    + Support renaming read-only files.
  * Fixed:
    + File filter reset when file is opened.
    + Crash when dragging row in import table.
    + Blocking when jumping to vanished previous or next file.
    + Support languages with code or modifier.
    + Hide text fragments visible in header of frame table columns.
    + English plural forms.
    + Add missing license files.
    + Support large files on Windows (64-bit).
* Wed Jan 29 2020 olaf@aepfle.de
- Use plain python to refer to a specific version of python
* Wed Jan 29 2020 Dave Plater <davejplater@gmail.com>
- Fix build with python 3.6 by specifying UTF8 locale.
* Thu Jan 23 2020 enzokiel@kabelmail.de
- update to version 3.8.2
  * New:
    + Catalan, Portuguese and Ukrainian translations.
  * Fixed:
    + Crash when removing M4A atoms.
* Mon Dec 23 2019 enzokiel@kabelmail.de
- update to version 3.8.1
  * New:
    + Show number of files in status bar.
    + Support regular expressions in string replacements.
  * Improved:
    + Support format codes in "Filename for cover" in
    "ExtractAlbum Art" script.
    + The order of string replacements is respected.
    + Show RVA2 identifier in frame table.
    + Show UFID owner in frame table.
    + Support setting file name with "Import from Tags".
  * Fixed:
    + Android: Accept changes when focus is lost and Enter not
    pressed.
    + Self-contained Linux package: Correctly change RPATH in
    plugins.
    + Self-contained Linux package: Support composed accented
    characters.
    + QML scripts: Skip "--" argument, which is used when passing
    parameters from qml tool.
    + Show UFID values in frame table.
* Sat Aug 24 2019 enzokiel@kabelmail.de
- update to version 3.8.0
  * New:
    + kid3-cli: Support JSON output.
    + Format codes %%{modificationdate} and %%{creationdate}.
    + Support ID3v2 GRP1 frame introduced with iTunes 12.5.4.
    + Import from Tags function which operates on selected files.
    + Explicit frame names can be used by prepending a '!'
    character.
  * Improved:
    + Adapt unified frame type mapping for better iTunes
    compatibility.
    + Support multiple covers in M4A files.
    + kid3-cli: Remove dependencies to GUI libraries.
    + Android: Show info how to write to SD card.
    + Android: Support Qt 5.12.
  * Fixed:
    + Use file settings to replace illegal characters when renaming
    directories.
    + Self-contained Linux package: Provide libraries to run QML
    console.
* Sat Mar 30 2019 enzokiel@kabelmail.de
- update to version 3.7.1
  * New:
    + Support max-, min-, unq- aggregation when renaming
    directories.
    + Android: Support dark and light themes.
    + Android: Support opening files with Kid3 from other apps.
    + Android: Settings for formats, character replacements and
    import profiles.
  * Improved:
    + Support format codes in file name for cover.
    + Support WMV extension.
    + Android: Better file select dialog.
  * Fixed:
    + Support setting of ID3v2 version for DSF files.
    + Avoid jumping around frames while deleting.
    + Removal of multiple tags where not all tags are removed.
    + Setting of a simple string as value for IPLS frame with
    TagLib.
    + Adapted to Discogs server update.
    + Windows: Avoid insert disk dialog.
    + Android: Save settings when app is suspended.
    + Android: GUI updates on changes.
* Mon Jan 14 2019 enzokiel@kabelmail.de
- update to version 3.7.0
  * New:
  - Add and reorder playlist items using drag'n'drop.
  - Edit tags from files referenced in playlist.
  - Play songs from playlist.
  - Drag image files from file list to embed them in audio files.
  - Drag files from file list into other applications.
  - Reload action to refresh file list.
  - Completions with different values when selecting multiple
    files.
  - Option "--dbus" to have a D-Bus interface with kid3-cli.
  - Code "%%{dirname}" to use current directory name when renaming.
  - Code "%%{disk}" as alias for "%%{disc number}".
  - Edit list of availble formats to set file and directory names
    from the tags and vice versa.
  * Improved:
  - Reduce number of open file handles.
  - Allow user to resize file and directory list columns.
  - Modernize code base, support only Qt 5, C++11, CMake 3.
  * Fixed:
  - Add a number if a file is renamed with an existing name.
  - Avoid losing changes when a directory is renamed.
  - Change notifications for files in renamed directory.
* Sun Aug 26 2018 enzokiel@kabelmail.de
- update to version 3.6.2
  * Improved:
    + Format from tags with custom strings prepended/appended when
    replaced format code is not empty %%{"t1"code"t2"}.
  * Fixed:
    + MP4 free form names longer than 4 characters with TagLib.
    + Support DOS line endings with "Import CSV".
    + Set CTOC and CHAP element ID from values in the frame table.
    + Correctly add frame when "Edit" is clicked on non existing
    frame.
    + Show correct icon in Wayland session.
    + Improve editing of ISO date/time values with validation
    enabled.
    + Bundle OpenSSL libraries with self-contained Linux package.
- Some cleanings in spec file.
* Mon Apr 23 2018 enzokiel@kabelmail.de
- update to version 3.6.1
  * Improved:
    + Faster saving when many files are unchanged.
    + Do not change file extension when creating file name from
    tags.
    + Support for cross building.
  * Fixed:
    + Parsing of xid atom with Mp4v2Metadata plugin.
    + Scroll to opened file after sorting file list.
    + Avoid recursion when automatically applying format.
* Mon Mar 19 2018 enzokiel@kabelmail.de
- update to version 3.6.0
  * New:
    + New look for Android app using Qt Quick Controls 2.
    + Editor for star ratings, configurable mapping between rating
    values and number of stars.
    + Option to restrict length of file names.
    + Option to show hidden files in file and directory lists.
  * Improved:
    + Support adding unknown 4 letter atoms to M4A files.
    + Allow Camelot wheel value 1A-12A, 1B-12B for initial key.
  * Fixed:
    + Windows: Renaming directories which contain subfolders.
    + Adding and finding unified frames by their frame ID.
    + Deletion of M4A atoms which are not known or which have an
    unofficial free form prefix.
    + Support files with m4v extension.
* Tue Oct 31 2017 joerg.lorenzen@ki.tng.de
- update to version 3.5.1
  * Improved:
    + Compatibility of imported and exported CSV files with cells
    containing new line characters.
    + Do not show unknown frames for ID3v2.3 TDAT, TIME, TYER,
    TRDA frames.
    + Enable high-DPI scaling for Qt >= 5.6.
    + Change AppStream directory from appdata to metainfo.
  * Fixed:
    + Crash with DSF files having sample rates other than 2822400
    or 5644800.
* Fri Jun 16 2017 joerg.lorenzen@ki.tng.de
- update to version 3.5.0
  * New:
    + Tags which violate the ID3v2 standard are marked.
    + Filter for marked files.
    + Configurable keyboard shortcuts for user actions.
    + Set and get frame fields from scripts and CLI.
    + Select a subset of frames for copy, paste, remove from
    scripts and CLI.
    + Set and get multiple frames of the same kind from scripts
    and CLI.
    + Support field names in export and filter expressions.
    + Support xid and ownr atoms in M4A files.
    + Danish translation.
  * Improved:
    + Better performance when files are added to selection.
    + The script actions in the file list context menu only
    operate on selected files.
    + Only jump to tagged files with previous/next in GUI.
    + Show passed/total after "filtered" in title bar.
    + kid3-cli can run from a console without GUI/X11.
  * Fixed:
    + Adding and deleting tag 3 frames from CLI.
    + Deletion of multiple METADATA_BLOCK_PICTURE picture frames.
    + Wrong depth 32 instead of 24 stored in
    METADATA_BLOCK_PICTURE.
    + Use Ogg/Vorbis Comment field name setting also for Opus
    files.
* Fri Feb 24 2017 joerg.lorenzen@ki.tng.de
- update to version 3.4.5
  * New:
    + Settings to include and exclude folders in the file list.
  * Improved:
    + Use HTTPS for imports where possible.
    + Much faster expanding of the file list by avoiding GUI
    updates during the operation.
    + Faster filtering by avoiding GUI updates during the
    operation.
    + Reduced memory usage when filtering.
    + Updated Czech and Dutch translations.
  * Fixed:
    + Import from MusicBrainz.
    + Rate limit for import from Discogs.
    + Do not display multiple frames of same type as different.
    + Application not responsive when using a new filter after
    filtering a huge number of files.
    + Application not responsive when loading the tags after
    selecting a lot of files, is now abortable.
    + Terminate kid3-cli if EOF is received.
* Fri Dec 23 2016 joerg.lorenzen@ki.tng.de
- update to version 3.4.4
  * New:
    + If the first command line argument is "--portable",
    the configuration is stored in a file kid3.ini in the
    program folder.
    + Image data can be copied to clipboard.
    + MPRIS2 D-Bus interface for the audio player.
  * Improved:
    + "Import CSV" can import to different files if no matching
    file paths found.
  * Fixed:
    + Importing of durations from text formats (file/clipboard).
    + Building with Chromaprint 1.4.
* Fri Dec  2 2016 joerg.lorenzen@ki.tng.de
- update to version 3.4.3
  * New:
    + The RIFF track field name is configurable (IPRT, ITRK, TRCK)
    for better interoperability.
    + The RIFF chunk name for ID3v2 tags in WAV files is configurable
    (ID3, id3) for better interoperability.
    + ID3v2 tags in WAV files can have version 2.3.0 or 2.4.0.
  * Improved:
    + Support new classical music frames introduced with iTunes 12.5.
  * Fixed:
    + Use the last sort order and column for the file list on startup.
    + Display expected ID3v2 version if no ID3v2 tag exists yet.
    + Tag 3 can be addressed in kid3-cli by number "3".
    + Support translated display frame names in kid3-cli.
    + Avoid crash when pictures in FLAC files are empty or too large.
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Thu Aug 25 2016 joerg.lorenzen@ki.tng.de
- update to version 3.4.2
  * Fixed:
    + Embed Lyrics works again with makepersonal.co and
    lyrics.wikia.com.
    + Do not add an empty frame when deleting a non existant frame
    in kid3-cli.
    + Support setting multiple frames of the same type with
    copy/paste.
    + Allow editing of quick access frames which are not yet present
    in the file.
    + Reset shortcuts and appearance configuration when the defaults
    are restored in the settings.
  * Improved:
    + Do not show any disabled tag values in the Tag 1 section
    for files which do not support an ID3v1 tag.
    + Set the file filter for the file list in the file settings,
    not with the filter used in the open dialog.
    + Disable the global app menu on Ubuntu's Unity desktop.
- Removed conditional 'ffmpeg' because the required libraries are
  available in OBS.
- Added %%bcond 'build_qt5' to build against qt5 for openSUSE > 13.2
  and SLE (inclusive Leap 42.x).
- Added %%bcond 'build_kde' to build against kde4/kf5 for all
  distributions except SLE 12 (on PMBS kid3 can be successfully
  build without KDE frontend).
- Deleted devel files libkid3-*.so because they are not needed and
  removed kid3-rpmlintrc.
- Removed unneeded buildrequires libtunepimp-devel and changed some
  buildrequires to pkgconfig() and cmake().
- Add gpg signature as source (file kid3-3.4.2.tar.gz.asc).
- Added buildrequires hicolor-icon-theme, needed by post(un)
  srcipts %%icon_theme_cache_post(un).
- Small changes in options for cmake, enabled build of QML and
  added build/install for SLE 12 (only components QT and CLI).
- Removed manual installation on manpage for kid3 as it's installed
  during build process.
- Moved kid3 manpages from package kid3 to package kid3-core,
  manpages kid3-cli and kid3-qt are only symlinks and require
  manpage kid3.
* Mon Aug  8 2016 olaf@aepfle.de
- Remove duplicate and misplaced cmake flag to enable ffmpeg
* Thu Jul 28 2016 olaf@aepfle.de
- Convert BuildRequires libchromaprint-with-ffmpeg to pkgconfig
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditionally
* Thu Jun 23 2016 davejplater@gmail.com
- Update to version 3.4.1
- Upstream changes:
  * Fixed:
  + Avoid wrong marking of ID3v2 Date frames as modified.
  + Enable setting M4A, Vorbis date with ISO date/time also when no
    tag exists.
  3.4.0:
  * New:
  + Support more than two tags for MP3 files with ID3v1, ID3v2 and APE
    tags, FLAC files with ID3v1, ID3v2 and Vorbis tags.
  + Support RIFF INFO tags in WAV files.
  + Filename to tag format can be defined as a regular expression with
    captures.
  + Perl regular expressions with Qt 5.
  * Improved:
  + Import from tags is also available from CLI, QML and D-Bus.
  + Help for editing synchronized lyrics.
  + Handle redirects when downloading.
  * Fixed:
  + KDE 5: Jumping to a specific help topic.
  + Enable setting ID3v2.4 date with ISO date/time also when no tag
    exists.
  + Crash when writing to a FLAC file which cannot be opened.
* Sat Apr 16 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
* Tue Mar 15 2016 davejplater@gmail.com
- Update to Release 3.3.2
- Upstream changes:
  * New:
    + Setting for text encoding used in playlists and exports.
  * Improved:
    + Support removing tags in MPC, WavPack with TagLib 1.11.
  * Fixed:
    + Stripping of ID3v2 tags from WAV files with TagLib 1.11.
    + Adapted to Discogs server update.
* Wed Dec 23 2015 davejplater@gmail.com
- Added conditional for kf5 to build in openSUSE:Leap:42.1
* Thu Dec 17 2015 ecsos@opensuse.org
- update to version 3.3.1
  * New:
  + Package for Android.
  + Support setting of data in GEOB frames from CLI and scripts.
  + Icons for high pixel density displays.
  * Improved:
    + Trim values from tags in format strings to avoid whitespace when
  setting file names from tags.
  + Updated Czech translation.
  * Fixed:
    + List picture in get command of kid3-cli also if its description
    is empty.
    + Set configured text encoding in picture frames.
    + Make file renaming work when saving non writable files.
    + Use high resolution icon in task switcher.
    + Avoid cropping in picture preview window on high pixel density
    displays.
* Thu Oct  1 2015 davejplater@gmail.com
- Update to version 3.3.0.
- Upstream changes:
  * New:
    Make order of quick access frames configurable.
    Support separators and submenus in user action context menu.
    Restore defaults button in settings dialog.
    CSV import from multiple directories.
    Support for lyrics.wikia.com in embed lyrics script.
    Support for chapter and table of contents audiobook frames.
    Mac, Windows: Support for podcast frames.
  * Improved:
    Display user friendly names for all supported frames.
    Updated Czech translation.
    Change file permissions in the case of modified file names.
  * Fixed:
    Wrong and missing translations.
    Removing ID3v1 genre with id3lib.
    KDE5:Name filters used in file dialogs, blocking file dialogs.
    KDE5: Invoking help in settings dialog.
    KDE4: Build with kdelibs-4.14.11.
    Qt5.5: Spurious popping up of download dialog.
    Do not abort build if qmlplugindump cannot be started.
* Wed Jun 10 2015 tittiatcoke@gmail.com
- Combine the kid3 and kid3-kf5 packages in a single spec-file and
  build the KF5 based version for openSUSE > 13.2
* Sat Apr 18 2015 davejplater@gmail.com
- Renamed kf5-kid3 to kid3-kf5
* Mon Mar 30 2015 joerg.lorenzen@ki.tng.de
- Added conflict of kid3-core and kf5-kid3-core to kf5-kid3.spec
* Fri Mar 20 2015 joerg.lorenzen@ki.tng.de
- Created package kf5-kid3
* Wed Mar 18 2015 joerg.lorenzen@ki.tng.de
- update to version 3.2.0
  * New:
    + Support QML/JS scripts for user actions.
    + Batch embed, export, and resize album art.
    + Batch lyrics download.
    + Recursive tag export.
    + Support build with KDE 5.
    + Support DSF files with TagLib 1.9.1.
    + Option to mark pictures larger than a given size.
    + Number tracks can reset track number for each folder.
    + Number tracks can only format numbers or set total.
    + Only expand subtree if shift is pressed with "Expand all".
    + Support Ogg FLAC files.
    + QML plugin.
  * Improved:
    + File suffix for export (e.g. picture) is determined by mime type.
    + Image dimensions are displayed below picture.
  * Fixed:
    + Crash when TagLib file is saved with changes in tags and file name.
    + Deletion of picture frames from Ogg/Opus files.
    + Setting description of Ogg pictures in frame table.
    + Reactivate support for AAC and MP2 files with TagLib.
    + Mac OS X: Avoid excessive memory consumption.
    + Adapted to Discogs server update.
    + Adapted to Amazon server update.
  - Added file kid3-rpmlintrc to suppress error messages.
* Sat Jan 24 2015 benoit.monin@gmx.fr
- update to version 3.1.2
  * New:
    + Allow user to change the file permissions of read-only files.
  * Improved:
    + Updated Simplified Chinese translation.
    + Reduce number of open file descriptors with TagLib >= 1.8.
  * Fixed:
    + Adapted to Discogs server update.
    + Correctly add missing frames when editing multiple files.
    + The value of an existing frame on multiple files can be set
    via D-Bus.
    + File names with special characters in Mp4V2Metadata on
    Windows.
    + Appdata passes appdata-validate check.
* Sat Sep 27 2014 davejplater@gmail.com
- Added conflict for kid3-qt4 from KDE:Extra which is no longer
  built.
* Sat Sep 20 2014 davejplater@gmail.com
- Update to version 3.1.1 a separate build for kid3-qt is no longer
  necessary and a cli version is added.
- Upstream Changes:
  * New:
  + Validation for date/time, track and disc number frames.
  + Timeout command in kid3-cli to overwrite command timeout.
  + Build option WITH_NO_MANCOMPRESS to disable gzipped manpages.
  * Improved:
  + Updated Czech translation.
  + Support drag'n'drop from https, ftp.
  + Show picture type in frame table.
  + Allow import from file/clipboard with empty date fields.
  + Add AppData and comment in desktop file for GNOME Software.
  + Handling of RPATH to private libraries.
  * Fixed:
  + Setting of POPM frames using kid3-cli.
  + Removing of COMM, PRIV, TXXX, free form frames.
  + Restore Ogg files if writing fails.
  + Format while editing for tag 2.
  + Support composer when importing from MusicBrainz.
  + Opening external links from handbook.
* Mon Jun  2 2014 toddrme2178@gmail.com
- Add xslt-tools dependency required by some openSUSE versions.
* Wed Apr 30 2014 tittiatcoke@gmail.com
- We are installing libraries into an unknown directory, so we need
  post and postun scripts to call for ldconfig. As that the
  library path is not standard, use this as a parameter to ldconfig
* Mon Apr 28 2014 toddrme2178@gmail.com
- Update to version 3.1
  * New:
    + Support for synchronized lyrics and event timing codes.
    + Import and export of LRC (synchronized lyrics/Karaoke) files.
    + Find and replace strings in tags and file names.
    + Display details and sort columns in file list.
    + Open and Open Containing Folder file list actions.
    + Support Ogg and Opus cover art.
    + Export format CDRDAO TOC for CDs with CD-text from WAV tags.
    + D-Bus command expandFileList() to expand the whole file list.
  * Improved:
    + Updated Czech, Finnish, Estonian translations.
    + GUI and usability, keyboard navigation.
  * Fixed:
    + Restore Quick Access Tags settings properly.
    + Support tags from file name with
    2 character extensions (e.g. ".wv").
    + Keyboard shortcuts settings with Mac OS X 10.9.
    + Build without Phonon.
    + Fingerprint decoding and resampling with libav.
    + D-Bus command expandDirectory().
- Update to version 3.0.2
  * Fixed:
    + Translations and handbook are not found on
    Mac OS X 10.9 Mavericks.
    + Application termination when main window is
    closed while handbook is open.
    + Tag 1 genre combobox is empty if
    "show only custom genres" is set.
    + Session restoration.
    + Detection of installed Qt 5.
    + KDE application does not find libraries
    if prefix is not /usr.
    + Build if all translations are disabled.
  * Improved:
    + Added new genres introduced in Winamp 5.6.
- Update to version 3.0.1
  * Fixed:
    + Filename format configuration can not be changed.
    + Menus get broken when toolbar is changed in KDE version.
    + Incorrect conversion of configuration in KDE version.
    + Unintended result selection in
    first track of fingerprint import.
    + Crash at exit after canceling
    fingerprint import with GStreamer.
    + Prefer GStreamer 0.10 over 1.0 to avoid hang in Phonon.
    + Build with readline needing termcap
    (as used in Slackware).
    + Build with FFmpeg 2.0 (as used in openSUSE 12.3).
    + Honor LIB_SUFFIX if set (as used in Fedora).
- Update to version 3.0
  * New:
    + Command-line interface kid3-cli.
    + Use common shared libraries for
    KDE, Qt-only and CLI versions.
    + Plugins for metadata libraries and importers.
    + Support Opus files with TagLib 1.9.
    + Support GStreamer 1.0.
    + Support libavresample 0.0.3.
  * Improved:
    + Editing without leaving the keyboard.
    + When saving a file fails, tell
    user if it is not writable.
    + Escape metacharacters in HTML export.
    + Updated Czech translation.
    + Updated Finnish translation.
    + Cleaned up configuration option sections.
  * Fixed:
    + Crash when saving non-FLAC file with flac extension.
    + Support minimum Mac OS X version 10.5.
    + Load Qt libraries only from bundle on Mac OS X.
- Merge qt package into subpackage, and add core and cli
  subpackages per upstream recommendation.
- Remove obsolete patches:
  * kid3-qt-gcc47.patch
  * kid3-2.3-gstreamer1.0.diff
- Remove tests for obsolete openSUSE versions.
- Make sure phonon gstreamer version
  matches kid3 gstreamer version
- Split documentation packages.
* Sun Aug 11 2013 hrvoje.senjan@gmail.com
- Fixed %%{?suse_version} conditional in kid3.spec
* Sat Jun  1 2013 hrvoje.senjan@gmail.com
- Added kid3-2.3-gstreamer1.0.diff, enables gstreamer 1.0 support
- Add Source URL
* Sat Mar 23 2013 davejplater@gmail.com
- Merge kid3 and kid3-qt packages by linking KDE:Extra/kid3 to the
  kid3-qt package.
* Sat Mar 16 2013 dmitry_r@opensuse.org
- Update to version 2.3
  * New:
    + Automatic batch import for multiple directories.
    + Import catalog number and release country from Discogs and
    MusicBrainz.
    + Quick access tags are configurable for tag 2.
    + Setting for default file name to save cover art.
    + Select all in directory.
    + Apply text encoding.
    + Support Qt 5.0.
  * Improved:
    + Better responsiveness when working with a huge number of files,
    long operations can be aborted (filtering, renaming, expanding).
    + Support custom frame names in formats and imports.
    + Display accuracy and cover art URL for imports.
    + Added more unified frame types.
    + GUI and usability.
  * Fixed:
    + Swapped mapping of too and enc for M4A files.
    + Compatibility of ID3v2.4.0 COMM frames with iTunes.
    + Do not remove spaces in Vorbis comment field names.
    + Crash and decoding for fingerprints with libav 9.1.
* Fri Dec 28 2012 dmitry_r@opensuse.org
- Enable chromaprint support
* Sat Dec 15 2012 hrvoje.senjan@gmail.com
- Update to version 2.2.1
- Changes since 2.1:
  * New:
    + Option to load last opened file on startup.
    + Option to use locale for character conversion.
    + Support new features of TagLib 1.8: More
    ID3 frames, ID3v2.3, tracker modules (MOD, S3M, IT, XM).
    + Support use of GStreamer instead of FFmpeg for
    Chromaprint decoding.
    + Support building with latest libav/FFmpeg libraries.
  * Improved:
    + Extract year from "YYYY-MM.." date frame for %%{year}
    format code.
    + Character conversion for roman numbers.
    + Dutch translation.
    + Finnish translation.
    + Czech translation.
  * Fixed:
    + Avoid crash when exporting album cover while editing multiple
    files.
    + Check if file format supported before converting to
    ID3v2.3.0.
    + Rewritten Discogs import to use Discogs API v2.0.
    + Fixed selection of language and handbook with Qt 4.8.
* Sun May 13 2012 mlin@suse.com
- Update to version 2.1
  * New:
    + Keyboard shortcuts configuration for Qt-only version.
    + Use Chromaprint for import from MusicBrainz Fingerprint, is now
    also available on Windows and Mac OS X.
    + Serbian translation.
    + Support build with Qt5.
  * Improved:
    + Support most frames in format codes with %%{framename}.
    + Support iTunes ID3v2.4 frames TCMP, TSO2, TSOC.
    + Option to use the native file dialogs for Qt-only version.
    + Handling of pictures in WMA files.
    + Use themed icons.
    + Building with shared libraries on KDE.
    + Handle carriage return characters in output from user commands.
  * Fixed:
    + Windows: Avoid truncation of file when renaming with illegal
    characters.
    + Limit number of open file handles.
    + Nicer icons, install SVG instead of SVGZ in kid3-qt.
    + Fixed import from Amazon.
    + Adapted to Discogs server update.
- Disable build with chromaprint that require ffmpeg
* Thu Nov  3 2011 asterios.dramis@gmail.com
- Update to release 2.0.1:
  * Fixed:
    + Prevent cursor from jumping to end in format line edits.
    + Correctly update file selection after add, edit or delete frame.
    + Build system finds DocBook XSL on various Linux distributions,
    finds Phonon on Ubuntu 11.10, can build with shared libraries.
    + Correctly set bundle version on Mac OS X.
    + Czech translation.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Removed Provides:/Obsoletes: entries for kde4-kid3 (not needed anymore, it
    was last used at 2009-11-04).
* Tue Sep  6 2011 asterios.dramis@gmail.com
- Update to release 2.0
  * New:
    + Import from tags to extract and move information between tags.
    + Play a track on double click (optional).
    + Searching in help browser.
    + Move files to trash instead of deleting them.
    + Automatic setting of checkboxes when frame is changed.
    + Support for APE tags with TagLib 1.7.
  * Improved:
    + Major refactoring to improve software architecture, separated
    GUI from application logic using the Qt 4 Model/View
    architecture. This required dropping support for Qt 3 and
    KDE 3. Unified build system using CMake for KDE and Qt-only
    versions.
    + The file list is updated on file system changes and is faster.
    + Import sub-dialogs are modeless and do not block import dialog.
    + Import table is editable and has optional columns for file
    names and paths (selectable with context menu).
    + The tracks to import can be selected, e.g. to import only one
    CD from a doulbe-CD album.
    + Number Tracks can number the tracks of multiple directories.
    + Multiple directories can be selected with Rename Directory.
    + M4A support with TagLib (can fully replace libmp4v2).
    + Exports are displayed in a table if they contain tabulators.
    + Adding and editing formats is now more user friendly.
    + GUI and usability.
  * Fixed:
    + Genre and track total in M4A files with TagLib.
    + Execution of user action without command.
    + Adapted to Discogs server update.
- Spec file updates:
  * Changed License: to GPL-2.0+.
  * Removed docbook-xsl-stylesheets and added libogg-devel in BuildRequires:.
  * Removed support for openSUSE < 11.2 in spec file.
  * Minor other updates.
* Sun Apr 10 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Removed "licenses" package usage.
  * Recommends: instead of Suggests: for kid3-lang package.
  * Minor other updates.
* Tue Feb 15 2011 davejplater@gmail.com
- Removed conflicting kid3-qt, kid3-qt is already in factory, 11.4
  developed in multimedia:apps.
* Sun Feb  6 2011 asterios.dramis@gmail.com
- Update to release 1.6
  * Improved:
    + The total number of tracks can be set in the "Number Tracks" dialog.
    + All numeric fields can be padded with zeros.
    + Parts of the filename can be ignored when generating tags from the
    filename.
    + Updated Estonian, Italian and Czech translations.
  * Fixed:
    + Track number digits option works now with ID3v2.4 and UTF8/UTF16.
    + Adapted to Discogs server update.
- Spec file updates:
  * Added a kid3-qt package without KDE dependencies and also its respective
    lang package.
  * Added a kid3-lang package.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires:, %%build, %%install and %%files sections.
* Fri Oct  8 2010 davejplater@gmail.com
- Update to release 1.5
- Upstream changes :
  Faster filtering,
  simple audio player,
  GUI and usability improvements.
* Wed Sep 22 2010 davejplater@gmail.com
- Update to svn 714
- Upstream changes :
  * fixed Doxygen warnings
  * updated translations
  * do not display [filtered] after filtering "All"
  * display Phonon errors in status bar
  * use less size for format comboboxes
  * version 1.5, updated documentation
  * "Show Statusbar" option for Qt only version
  * double click on picture to add/edit
  * fixed bug: after album cover was downloaded by import it was downloaded
  again in next import because the import track data was not properly cleaned
  * move "From Filename" buttons up to corresponding format combobox as
  "To Tag" buttons
  * update fixdocbook.pl for changes made in commit "Make docs compile
  against KDE 4.5 beta"
  * added Chinese translation
  * changed player dockwidget into a toolbar
  * Auto Hide Tags option to hide unused tags
  * use QDockWidget for PlayDialog, make it a child of main window
  * make play action available in Tools menu and toolbar
  * simple audio player available via context menu
  * icons and toolbar for Qt only version
  * use latest versions of libraries
  * recent files menu for versions without KDE
  * context menu items "Expand all" and "Collapse all"
  * fix compilation with Qt 3 of MP4 and ASF pictures starting with TagLib 1.6.2
  * support APE files with TagLib > 1.6.3 (not officially released yet)
  * support MP4 and ASF pictures starting with TagLib 1.6.2
  * option to set number of digits in track number
  * commitData and closeEditor when the window is deactivated while a cell
  is being edited (i.e. the cell is not closed by pressing Enter), this
  is done to avoid losing the focus
  * fixed bug 3009738 URL (WXXX) tags incorrectly saved, the value was
  written to the Description instead of to the URL field
  * use correct extension for ".aac" and ".mp2" files when generating
  filenames from tags
  * removed MIME type inode/directory, there were problems on Archlinux
  * do not add multiple frames of the same type in filterDifferent()
  * more efficient handling of file selection for Qt 4
  * fixed setFrame() to work again with pictures
  * speed up filter, fixed deleteFrame() to work with single named frame,
  fixed addFrame() to update the preview picture also in the case of an
  explicitly passed frame
  * filterDifferent() will now result in a FrameCollection containing all
  frames of the other collection, so that the union of the frames of all
  selected files will be displayed
* Mon Jun  7 2010 davejplater@gmail.com
- Update to svn 673
- Upstream changes :
  * replaced xmms by amarok in context menu
  * Make docs compile against KDE 4.5 beta.
  * Add the official audio/ogg MIME type, remove the obsolete
  * x-directory/normal MIME type, add StartupNotify and StartupWMClass.
  * Finnish translation spelling fix.
* Sun Mar  7 2010 zOOmER.gm@gmail.com - 1.4
- gzip archive used for souce tarball
- updated to version 1.4
  + New:
  ++ Support for cover art in Ogg files.
  ++ Import from Amazon.
  ++ Separate formats for "to filename" and "from filename".
  ++ Czech translation.
  + Improved:
  ++ Use of UTF8 and UTF16 encoding when non-ASCII characters are used.
  ++ GUI and usability.
  + Fixed:
  ++ Correctly set tags when tags of multiple files are selected,
    edited, and then copied to the other tag.
  ++ Adapted to Discogs server update.
- removed unnecessary BuildRequires
- fixed file list for older distributions
* Wed Nov  4 2009 buschmann23@opensuse.org - 1.3
- renamed package from kde4-kid3 to kid3
- updated to version 1.3
  + New:
  ++ Advanced playlist dialog.
  ++ Support for WMA/ASF, AIFF and WAV files.
  ++ Estonian, Finnish and Turkish translations.
  + Improved:
  ++ When changing the current file while a tag field is being edited,
    the changes are preserved.
  ++ Translation system.
  ++ Settings in Number Tracks dialog can be saved.
  ++ Filter files without attached pictures.
  ++ Support for libmp4v2 1.9 and TagLib 1.6.
  + Fixed:
  ++ Show album art when multiple files are selected.
  ++ From Tag 2 option can be restored in Rename Directory dialog.
  ++ Picture download.
  ++ Adapted to Discogs server update.
* Sat May  2 2009 donnie.bhayangkara@opensuse.org
- new upstream version
* Sat Oct 25 2008 donnie.bhayangkara@opensuse.org
- new upstream version
* Thu Apr  3 2008 donnie.bhayangkara@opensuse.org
- new upstream version:
  New:
  * File filter.
  * D-Bus interface to control application by scripts.
  * Long format codes %%{title}, %%{album}, ... and tooltips for formats.
  * Support for FLAC pictures.
  * Polish translation.
  Improved:
  * GUI and usability.
  * Rename directory wizard.
  * Use xdg-open as the default web browser.
  * Display description instead of TXXX and WXXX.
  * Add pictures to files by drag and drop and from cllipboard.
  * Compilation with GCC 4.3 and compiler detection for kid3-qt.
  * Support for TagLib 1.5.
  Fixed:
  * KDE 4 docs in correct directory.
  * Crash when TSST frame was added to ID3v2.3.0 tag.
  * Disappearing ID3v1 genres.
  * Possible crash when import or export format was added.
* Sun Dec  2 2007 donnie.bhayangkara@opensuse.org
- new upstream version:
  New:
  * All frames can be edited in tables, not only the standard tags.
  * Support for MP4/AAC, MP2, Speex, TrueAudio, and WavPack files.
  * Default encoding can be configured.
  * Italian translation.
  * Support build with KDE 4.
  Improved:
  * Conversion between ID3v2.3 and ID3v2.4 for all supported frames.
  * GUI and usability.
  * Qt4 version builds without Qt3Support module
  Fixed:
  * Correct kid3-qt icon.
  * kid3-qt builds correctly without id3lib or without MusicBrainz.
  * Remove deleted user actions from configuration.
  * Allow new export/import formats with empty fields.
  * Reread file after conversion from ID3v2.4 to ID3v2.3.
  * Rename directory does not rename when tags are empty.
* Wed Jun 13 2007 donnie.bhayangkara@opensuse.org
- new upstream version:
  New:
  * Hierarchical directory tree instead of flat file list.
  * Enhanced context menu commands, can be used to browse for lyrics
    and album art.
  * Import from gnudb.org.
  * Conversion between ID3v2.3 and ID3v2.4 tags.
  * Editor for custom genres.
  * Option to mark truncated ID3v1.1 fields.
  Improved:
  * Frames are listed alphabetically and can be edited and deleted
    in multiple files.
  * Import from TrackType.org (formerly freedb2.org)
    Fixed:
  * MusicBrainz fingerprint import.
* Thu Dec 21 2006 donnie.bhayangkara@opensuse.org
- package for v0.8.1
